@@ -515,6 +515,18 @@ changeGroupBindings:
   # delay other resources with load balancer provisioning
   # - apiVersionKindMatcher: {kind: Service, apiVersion: v1}
 
+- name: change-groups.kapp.k14s.io/serviceaccount
+  resourceMatchers: &serviceAccountMatchers
+  - apiVersionKindMatcher: {kind: ServiceAccount, apiVersion: v1}
+
+- name: change-groups.kapp.k14s.io/kapp-controller-app
+  resourceMatchers:
+  - apiVersionKindMatcher: {kind: App, apiVersion: kappctrl.k14s.io/v1alpha1}
+
+- name: change-groups.kapp.k14s.io/kapp-controller-packageinstall
+  resourceMatchers:
+  - apiVersionKindMatcher: {kind: PackageInstall, apiVersion: packaging.carvel.dev/v1alpha1}
+
 changeRuleBindings:
 # Insert CRDs before all CRs
 - rules:
@@ -582,6 +594,21 @@ changeRuleBindings:
       - notMatcher:
           matcher: *disableDefaultChangeGroupAnnMatcher
 
+- rules:
+  - "upsert before upserting change-groups.kapp.k14s.io/kapp-controller-packageinstall"
+  - "upsert before upserting change-groups.kapp.k14s.io/kapp-controller-app"
+  - "delete after deleting change-groups.kapp.k14s.io/kapp-controller-packageinstall"
+  - "delete after deleting change-groups.kapp.k14s.io/kapp-controller-app"
+  ignoreIfCyclical: true
+  resourceMatchers:
+  - andMatcher:
+      matchers:
+      - notMatcher: {matcher: *disableDefaultChangeGroupAnnMatcher}
+      - anyMatcher:
+          matchers:
+          - anyMatcher: {matchers: *serviceAccountMatchers}
+          - anyMatcher: {matchers: *rbacMatchers}
+
 - rules:
   - "upsert after upserting change-groups.kapp.k14s.io/storage-class"
   ignoreIfCyclical: true
